# Generated by Django 4.0.2 on 2022-02-08 18:39

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('drf_stripe', '0002_alter_feature_description_alter_price_freq_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='price',
            name='currency',
            field=models.CharField(default='usd', max_length=3),
            preserve_default=False,
        ),
    ]
